@@ -132,18 +132,33 @@ def main(options):
     """
     # read in config, set variable
     config = DnstestConfig()
+    if options.exampleconf:
+        config.set_example_values()
+        print(config.to_string())
+        raise SystemExit(0)
+
+    if options.promptconfig:
+        # interactively build a configuration file
+        config.prompt_config()
+        raise SystemExit(0)
+
     if options.config_file:
         conf_file = options.config_file
     else:
         conf_file = config.find_config_file()
     if conf_file is None:
-        print("ERROR: no configuration file.")
+        print("ERROR: no configuration file found. Run with --promptconfig to build one interactively, or --example-config for an example.")
         raise SystemExit(1)
     config.load_config(conf_file)
 
     if options.ignorettl:
         config.ignore_ttl = True
 
+    if options.configprint:
+        print("# {fname}".format(fname=config.conf_file))
+        print(config.to_string())
+        raise SystemExit(0)
+
     parser = DnstestParser()
     chk = DNStestChecks(config)
 
@@ -159,6 +174,7 @@ def main(options):
         fh = open(options.testfile, 'r')
     else:
         # read from stdin
+        sys.stderr.write("WARNING: reading from STDIN. Run with '-f filename' to read tests from a file.\n")
         fh = sys.stdin
 
     # read input line by line, handle each line as we're given it
@@ -203,6 +219,10 @@ def parse_opts():
     usage = "%prog [-h|--help] [--version] [-c|--config path_to_config] [-f|--file path_to_test_file] [-V|--verify]"
     usage += "\n\npydnstest %s - <https://github.com/jantman/pydnstest/>" % VERSION
     usage += "\nlicensed under the GNU Affero General Public License - see LICENSE.txt"
+    usage += "\nGrammar:\n\n"
+    parser = DnstestParser()
+    for s in parser.get_grammar():
+        usage += "{s}\n".format(s=s)
     p = optparse.OptionParser(usage=usage, version="pydnstest %s" % VERSION)
     p.add_option('-c', '--config', dest='config_file',
                  help='path to config file (default looks for ./dnstest.ini or ~/.dnstest.ini)')
@@ -219,5 +239,14 @@ def parse_opts():
     p.add_option('-t', '--ignore-ttl', dest='ignorettl', default=False, action='store_true',
                  help='when comparing responses, ignore the TTL value')
 
+    p.add_option('--example-config', dest='exampleconf', default=False, action='store_true',
+                 help='print an example configuration file and exit')
+
+    p.add_option('--configprint', dest='configprint', default=False, action='store_true',
+                 help='print the current configuration and exit')
+
+    p.add_option('--promptconfig', dest='promptconfig', default=False, action='store_true',
+                 help='interactively build a configuration file through a series of prompts')
+
     options, args = p.parse_args()
     main(options)
